@@ -388,6 +388,19 @@ class Resource(WADLResolvableDefinition):
                     return method
         return None
 
+    def parameters(self, media_type=None):
+        """A list of this resource's parameters.
+
+        :param media_type: Media type of the representation definition
+            whose parameters are being named. Must be present unless
+            this resource is bound to a representation.
+
+        :raise NoBoundRepresentationError: If this resource is not
+            bound to a representation and media_type was not provided.
+        """
+        return self._find_representation_definition(
+            media_type).params(self)
+
     def parameter_names(self, media_type=None):
         """A list naming this resource's parameters.
 
@@ -913,9 +926,23 @@ class Parameter(WADLBase):
         return [Option(self, option_tag)
                 for option_tag  in self.tag.findall(wadl_xpath('option'))]
 
+    @property
+    def link(self):
+        """Get the link to another resource.
+
+        The link may be examined and, if its type is of a known WADL
+        description, it may be followed.
+
+        :return: A Link object, or None.
+        """
+        link_tag = self.tag.find(wadl_xpath('link'))
+        if link_tag is None:
+            return None
+        return Link(self, link_tag)
+
     @property
     def linked_resource(self):
-        """Find the type of resource linked to by this parameter.
+        """Follow a link from this parameter to a new resource.
 
         This only works for parameters whose WADL definition includes a
         <link> tag that points to a known WADL description.
@@ -923,10 +950,10 @@ class Parameter(WADLBase):
         :return: A Resource object for the resource at the other end
         of the link.
         """
-        link_tag = self.tag.find(wadl_xpath('link'))
-        if link_tag is None:
+        link = self.link
+        if link is None:
             raise ValueError("This parameter isn't a link to anything.")
-        return Link(self, link_tag).resolve_definition()
+        return link.follow
 
 class Option(WADLBase):
     """One of a set of possible values for a parameter."""
@@ -949,7 +976,7 @@ class Link(WADLResolvableDefinition):
     """A link from one resource to another.
 
     Calling resolve_definition() on a Link will give you a Resource for the
-    type of resource linked to.
+    type of resource linked to. An alias for this is 'follow'.
     """
 
     def __init__(self, parameter, link_tag):
@@ -962,6 +989,28 @@ class Link(WADLResolvableDefinition):
         self.parameter = parameter
         self.tag = link_tag
 
+    @property
+    def follow(self):
+        """Follow the link to another Resource."""
+        if not self.can_follow:
+            raise WADLError("Cannot follow a link when the target has no "
+                            "WADL description. Try using a general HTTP "
+                            "client instead.")
+        return self.resolve_definition()
+
+    @property
+    def can_follow(self):
+        """Can this link be followed within wadllib?
+
+        wadllib can follow a link if it points to a resource that has
+        a WADL definition.
+        """
+        try:
+            definition_url = self._get_definition_url()
+        except WADLError:
+            return False
+        return True
+
     def _definition_factory(self, id):
         """Turn a resource type ID into a ResourceType."""
         return Resource(
